# AccessRequestsStatus

Contains a list of UserRequestInfo objects for a user with pending status or a user with at least one request. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user** | [**User**](User.md) |  | 
**user_requests** | [**list[UserRequestInfo]**](UserRequestInfo.md) | The matching UserRequestInfo objects | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


